@@ -1,5 +1,4 @@
 #!/usr/pkg/bin/python3.10
-# -*- coding: utf-8 -*-
 r"""
 Sphinx Gallery Notebook converter
 =================================
@@ -11,10 +10,9 @@ scripts into Jupyter Notebooks.
 # Author: Óscar Nájera
 # License: 3-clause BSD
 
-from __future__ import division, absolute_import, print_function
 
 from sphinx_gallery.notebook import python_to_jupyter_cli
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     python_to_jupyter_cli()
